@@ -8,4 +8,6 @@ _DEFAULT_SIMPLE_OUTPUT=false
 _DEFAULT_STOP_ON_FAILURE=false
 _DEFAULT_SHOW_EXECUTION_TIME=true
 _DEFAULT_DEFAULT_PATH=
+_DEFAULT_LOG_JUNIT=
+_DEFAULT_REPORT_HTML=
 CAT="$(which cat)"
