@@ -52,13 +52,13 @@ function helper::check_duplicate_functions() {
 #
 function helper::get_functions_to_run() {
   local prefix=$1
-  local filter=$2
+  local filter=${2/test_/}
   local function_names=$3
 
   local filtered_functions=""
 
   for fn in $function_names; do
-    if [[ $fn == ${prefix}_${filter}* ]]; then
+    if [[ $fn == ${prefix}_*${filter}* ]]; then
       if [[ $filtered_functions == *" $fn"* ]]; then
         return 1
       fi
@@ -86,7 +86,8 @@ function helper::unset_if_exists() {
 }
 
 function helper::find_files_recursive() {
-  local path="$1"
+  ## Remove trailing slash using parameter expansion
+  local path="${1%%/}"
 
   if [[ "$path" == *"*"* ]]; then
     eval find "$path" -type f -name '*[tT]est.sh' | sort | uniq
@@ -131,26 +132,6 @@ function helper::get_provider_data() {
   fi
 }
 
-function helper::get_multi_invoker_function() {
-  local function_name="$1"
-  local script="$2"
-  local multi_invoker_function
-
-  if [[ ! -f "$script" ]]; then
-    return
-  fi
-
-  multi_invoker_function=$(\
-    grep -B 1 "function $function_name()" "$script" |\
-    grep "# multi_invoker " |\
-    sed -E -e 's/\ *# multi_invoker (.*)$/\1/g'\
-  )
-  func_exists=$(declare -f "$multi_invoker_function")
-  if [[ -n "$func_exists" ]]; then
-    echo "$multi_invoker_function"
-  fi
-}
-
 function helper::trim() {
   local input_string="$1"
   local trimmed_string
@@ -168,3 +149,35 @@ function helpers::get_latest_tag() {
     sort -Vr |
     head -n 1
 }
+
+function helpers::find_total_tests() {
+    local files=("$@")
+    local total_count=0
+
+    for file in "${files[@]}"; do
+        local count
+        count=$(grep -r -E '^\s*function\s+test' "$file" --include=\*.sh 2>/dev/null | wc -l)
+        total_count=$((total_count + count))
+    done
+
+    echo "$total_count"
+}
+
+function helper::load_test_files() {
+  local filter=$1
+  local files=("${@:2}")
+
+  local test_files=()
+
+  if [[ "${#files[@]}" -eq 0 ]]; then
+    if [[ -n "${BASHUNIT_DEFAULT_PATH}" ]]; then
+      while IFS='' read -r line; do
+        test_files+=("$line")
+      done < <(helper::find_files_recursive "$BASHUNIT_DEFAULT_PATH")
+    fi
+  else
+    test_files=("${files[@]}")
+  fi
+
+  printf "%s\n" "${test_files[@]}"
+}
