@@ -4,18 +4,6 @@ function runner::load_test_files() {
   local filter=$1
   local files=("${@:2}") # Store all arguments starting from the second as an array
 
-  if [[ "${#files[@]}" == 0 ]]; then
-    if [[ -n "${DEFAULT_PATH}" ]]; then
-      while IFS='' read -r line; do
-        files+=("$line");
-      done < <(helper::find_files_recursive "$DEFAULT_PATH")
-    else
-      printf "%sError: At least one file path is required.%s\n" "${_COLOR_FAILED}" "${_COLOR_DEFAULT}"
-      console_header::print_help
-      exit 1
-    fi
-  fi
-
   for test_file in "${files[@]}"; do
     if [[ ! -f $test_file ]]; then
       continue
@@ -26,7 +14,7 @@ function runner::load_test_files() {
 
     runner::run_set_up_before_script
     runner::call_test_functions "$test_file" "$filter"
-    if [ "$PARALLEL_RUN" = true ] ; then
+    if [ "$BASHUNIT_PARALLEL_RUN" = true ] ; then
       wait
     fi
     runner::run_tear_down_after_script
@@ -67,7 +55,7 @@ function runner::call_test_functions() {
   functions_to_run=($(runner::functions_for_script "$script" "$filtered_functions"))
 
   if [[ "${#functions_to_run[@]}" -gt 0 ]]; then
-    if [[ "$SIMPLE_OUTPUT" == false ]]; then
+    if [[ "$BASHUNIT_SIMPLE_OUTPUT" == false ]]; then
       echo "Running $script"
     fi
 
@@ -75,22 +63,27 @@ function runner::call_test_functions() {
 
     for function_name in "${functions_to_run[@]}"; do
       local provider_data=()
-      IFS=" " read -r -a provider_data <<< "$(helper::get_provider_data "$function_name" "$script")"
+      while IFS=" " read -r line; do
+        provider_data+=("$line")
+      done <<< "$(helper::get_provider_data "$function_name" "$script")"
 
-      if [[ "${#provider_data[@]}" -gt 0 ]]; then
-        for data in "${provider_data[@]}"; do
-          runner::run_test "$script" "$function_name" "$data"
-        done
-      else
-        local multi_invoker
-        multi_invoker=$(helper::get_multi_invoker_function "$function_name" "$script")
-        if [[ -n "${multi_invoker}" ]]; then
-          helper::execute_function_if_exists "${multi_invoker}"
-        else
-          runner::run_test "$script" "$function_name"
-        fi
+      # No data provider found
+      if [[ "${#provider_data[@]}" -eq 0 ]]; then
+        runner::run_test "$script" "$function_name"
+        unset function_name
+        continue
       fi
 
+      # Execute the test function for each line of data
+      for data in "${provider_data[@]}"; do
+        # Split the line into individual arguments
+        IFS=" " read -r -a args <<< "$data"
+        if [ "${#args[@]}" -gt 1 ]; then
+          runner::run_test "$script" "$function_name" "${args[@]}"
+        else
+          runner::run_test "$script" "$function_name" "$data"
+        fi
+      done
       unset function_name
     done
   fi
@@ -189,19 +182,21 @@ function runner::run_test() {
     tail -n 1 |\
     sed -E -e 's/(.*)##ASSERTIONS_FAILED=.*/\1/g'\
   )
+  local total_assertions
+  total_assertions="$(state::calculate_total_assertions "$test_execution_result")"
 
   if [[ -n $runtime_error ]]; then
     state::add_tests_failed
     console_results::print_error_test "$function_name" "$runtime_error"
-    logger::test_failed "$test_file" "$function_name" "$start_time"
+    logger::test_failed "$test_file" "$function_name" "$start_time" "$total_assertions"
     return
   fi
 
   if [[ "$current_assertions_failed" != "$(state::get_assertions_failed)" ]]; then
     state::add_tests_failed
-    logger::test_failed "$test_file" "$function_name" "$start_time"
+    logger::test_failed "$test_file" "$function_name" "$start_time" "$total_assertions"
 
-    if [ "$STOP_ON_FAILURE" = true ]; then
+    if [ "$BASHUNIT_STOP_ON_FAILURE" = true ]; then
       exit 1
     fi
 
@@ -211,19 +206,19 @@ function runner::run_test() {
   if [[ "$current_assertions_snapshot" != "$(state::get_assertions_snapshot)" ]]; then
     state::add_tests_snapshot
     console_results::print_snapshot_test "$function_name"
-    logger::test_snapshot "$test_file" "$function_name" "$start_time"
+    logger::test_snapshot "$test_file" "$function_name" "$start_time" "$total_assertions"
     return
   fi
 
   if [[ "$current_assertions_incomplete" != "$(state::get_assertions_incomplete)" ]]; then
     state::add_tests_incomplete
-    logger::test_incomplete "$test_file" "$function_name" "$start_time"
+    logger::test_incomplete "$test_file" "$function_name" "$start_time" "$total_assertions"
     return
   fi
 
   if [[ "$current_assertions_skipped" != "$(state::get_assertions_skipped)" ]]; then
     state::add_tests_skipped
-    logger::test_skipped "$test_file" "$function_name" "$start_time"
+    logger::test_skipped "$test_file" "$function_name" "$start_time" "$total_assertions"
     return
   fi
 
@@ -232,7 +227,7 @@ function runner::run_test() {
 
   console_results::print_successful_test "${label}" "$@"
   state::add_tests_passed
-  logger::test_passed "$test_file" "$function_name" "$start_time"
+  logger::test_passed "$test_file" "$function_name" "$start_time" "$total_assertions"
 }
 
 function runner::run_set_up() {
